﻿/************************************************************************************************
Filename:	Program.cs
Author:		Microchip Technology Inc.
Compiler:	Microsoft C# 2010
Copyright © 2011 released Microchip Technology Inc.  All rights reserved.
MCHP License:
	MICROCHIP SOFTWARE NOTICE AND DISCLAIMER:  You may use this software, and any 
	derivatives created by any person or entity by or on your behalf, exclusively 
	with Microchip’s products.  Microchip and its licensors retain all ownership 
	and intellectual property rights in the accompanying software and in all 
	derivatives hereto.  
	This software and any accompanying information is for suggestion only.  It does 
	not modify Microchip’s standard warranty for its products.  You agree that you 
	are solely responsible for testing the software and determining its suitability.  
	Microchip has no obligation to modify, test, certify, or support the software.
	THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS".  NO WARRANTIES, WHETHER EXPRESS, 
	IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF 
	NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO 
	THIS SOFTWARE, ITS INTERACTION WITH MICROCHIP’S PRODUCTS, COMBINATION WITH ANY 
	OTHER PRODUCTS, OR USE IN ANY APPLICATION. 
	IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY, TORT 
	(INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT LIABILITY, INDEMNITY, 
	CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT, SPECIAL, PUNITIVE, EXEMPLARY, 
	INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, FOR COST OR EXPENSE OF ANY KIND WHATSOEVER 
	RELATED TO THE SOFTWARE, HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE 
	POSSIBILITY OR THE DAMAGES ARE FORESEEABLE.  TO THE FULLEST EXTENT ALLOWABLE BY LAW, 
	MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO THIS SOFTWARE WILL 
	NOT EXCEED THE AMOUNT OF FEES, IF ANY, THAT YOU HAVE PAID DIRECTLY TO MICROCHIP 
	FOR THIS SOFTWARE.
	MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF THESE TERMS.
Other License's:
	none
Revision History:
	  Date            Description
	------------------------------------------------------------------
	  12-13-2011     Initial release
************************************************************************************************/
using System;
//STEP 1: 
//   Add the DLL as a reference to your project through "Project" -> "Add Reference"
//   menu item within Visual Studio
using MCP2210;     //<---- Need to include this namespace

namespace MCP2210DLL_M_ExampleCode
{
	class Program
	{
		static void Main(string[] args)
		{
			//Variables
			const uint MCP2210_VID = 0x04D8;   // VID for Microchip Technology Inc.
			const uint MCP2210_PID = 0x00DE;   // PID for MCP2210
			bool isConnected = false;           // Connection status variable for MCP2210
			//STEP 2:
			//	Make an instance of the MCP2210.DevIO class by calling 
			//	the class constructor with the device VID and PID.
			MCP2210.DevIO UsbSpi = new DevIO(MCP2210_VID, MCP2210_PID);

			//STEP 3:
			//	Navigate the DLL classes to find your desired function. In this case, 
			//	we choose to check the connection status.
			isConnected = UsbSpi.Settings.GetConnectionStatus();

			//Print the result to the console window
			if (isConnected == true)
			{
				Console.WriteLine("The device is connected.\n");
				
				//
				// Other examples of DLL usage...
				//
				// Get power-up default SPI bit rate setting 
				int spiBitRate = UsbSpi.Settings.GetSpiBitRate(MCP2210.DllConstants.PWRUP_DEFAULTS_ONLY);
				Console.WriteLine("The SPI bit rate default setting is: " + spiBitRate.ToString());

				//Write to EEPROM
				int rslt = UsbSpi.Functions.WriteEEProm(12, 0);
				if (rslt == 0)	//Check if successful
				{
					Console.WriteLine("Wrote 0 to EEPROM address 12 successfully.");
				}
				else
				{
					Console.WriteLine("Encountered error " + rslt.ToString() + " when writing to EEPROM.");
				}

				// Get total number of devices plugged into PC
				int devCount = UsbSpi.Special.GetDevCount();
				Console.WriteLine("There are " + devCount.ToString() + " devices plugged into the PC.");
			}
			else
			{
				Console.WriteLine("The device is NOT connected.\n");
			}			
		}
	}
}
